# zot/service/rss.py
#
#

""" rss module. """

__copyright__ = "Copyright 2015, B.H.J Thate"

## IMPORTS

from zot.utils import parse_urls, short_date, fetch_url, error, strip_html
from zot.object import Object
from zot.looper import LOOPER
from zot.runtime import kernel

import threading
import logging
import socket
import time

## DEFINES

url1 = "http://feeds.nos.nl/nosnieuwspolitiek"

key_list = ["title", "link", "published"]

on_start = True

## display function

def display(*args, **kwargs):
    entry = args[0]
    result = ""
    for key in key_list: result += "%s - " % entry[key]
    kernel.announce(result[:-3])

## rss_get function

def rss_get(url):
    try:
        data = fetch_url("GET", url).read()
        data = fp.parse(data)
    except Exception as ex: error(url) ; return
    for entry in data["entries"]:
        if entry["link"] not in seen.list: seen.list.append(entry["link"])
        o = Object(entry)
        s = o.slice(key_list)
        if "summary" in o: o["summary"] = strip_html(o["summary"]).rstrip()
        o.prefix = "rss"
        o.short = short_date(time.ctime())
        o.sync()
    return o

## look function

def rss_fetch(*args, **kwargs):
    global on_start
    import zot.contrib.feedparser as fp
    seen = kernel.last("result", "rss")
    if not seen: seen = Object() ; seen.result = "rss" ; seen.list = []
    for obj in kernel.objects():
        if "rss" not in obj: continue
        if not obj.rss: continue
        counter = 1
        o = rss_get(obj.rss)
        display(o)
    seen.sync()

kernel.register("rss.fetch", rss_fetch)


kernel.register("rss.get", rss_get)

## RSS 

class RSS(LOOPER): pass

## INIT

def init(*args, **kwargs):
    rss = RSS(rss_fetch, 600)
    kernel.put(rss.start)
